# System Testing Report

## Software Information

Ubuntu 14.04 LTS

## Tests Results

### Uncategorisedfailed

job_id1 | failed |  | I/O log |
job_id2 | passed |  | I/O log | blah blah
job_id3 | skipped |  |  | No such device

### Resourcespassed

lsb | passed |  | I/O log |
package | passed |  | View |

### Attachmentspassed

dmesg_attachment | passed |  | View |

This report was created using Checkbox 1.0 on 2012-12-21T12:00:00

Copyright 2012 Canonical Ltd.

# Debian Packages

Name | Version
--- | ---
plainbox | 1.0
fwts | 0.15.2

# job 1

    FATAL ERROR

# job 2

    foo

# lsb

    description: Ubuntu 14.04 LTS

# dmesg_attachment

    bar